@@ -27,29 +27,25 @@ use crate::{
 
 pub fn remove_files(files: Vec<&str>) {
     for file in files {
-        if let Ok(_) = file_exists(file) {
-            if let Ok(_) = fs::remove_file(&file) {}
-        }
+        if file_exists(file).is_ok() && fs::remove_file(&file).is_ok() {}
     }
 }
 
 pub fn remove_files_with_prefix(prefix: &str) {
     if let Ok(paths) = glob(prefix) {
-        for entry in paths {
-            if let Ok(path) = entry {
-                if let Ok(_) = fs::remove_file(path.to_str().unwrap()) {}
-            }
+        for path in paths.flatten() {
+            if fs::remove_file(path.to_str().unwrap()).is_ok() {}
         }
     }
 }
 
 pub fn remove_folder(path: &str) {
-    if let Ok(_) = remove_dir_all(path) {}
+    if remove_dir_all(path).is_ok() {}
 }
 
 pub fn write_file(file_name: &str, bytes: &[u8]) -> Result<(), ExitFailure> {
     if let Ok(mut file) = std::fs::File::create(file_name) {
-        if let Err(_) = file.write_all(bytes) {
+        if file.write_all(bytes).is_err() {
             return throw_couldnt_write_to_file_msg(file_name);
         }
     }
@@ -64,18 +60,16 @@ pub fn read_file(file_name: &str) -> Option<String> {
 }
 
 pub fn file_exists_or_error(file_name: &str, label: &str) -> Result<(), ExitFailure> {
-    if let Err(_) = fs::File::open(file_name) {
+    if fs::File::open(file_name).is_err() {
         return throw_couldnt_open_file_msg(file_name, label);
     }
     Ok(())
 }
 
 pub fn create_folder_or_error(name: &str) -> Result<(), ExitFailure> {
-    if let Err(_) = fs::read_dir(name) {
-        if let Err(_) = fs::create_dir(name) {
-            // If not, create the folder
-            return throw_couldnt_create_folder_msg(name);
-        }
+    if fs::read_dir(name).is_err() && fs::create_dir(name).is_err() {
+        // If not, create the folder
+        return throw_couldnt_create_folder_msg(name);
     }
     Ok(())
 }
@@ -86,15 +80,15 @@ pub fn format_filename_test_case(folder: &str, prefix: &str, number: u32) -> Str
         return file_name;
     }
     let file_name = format!("{}/{}_0{}.txt", folder, prefix, number);
-    return file_name;
+    file_name
 }
 
 pub fn save_test_case(file_name: &str, from_path: &str) {
     // create test_cases folder
-    if let Ok(_) = create_folder_or_error(TEST_CASES_FOLDER) {}
+    if create_folder_or_error(TEST_CASES_FOLDER).is_ok() {}
     // Example: test_cases/testcase_tle_1.txt
     //let file_name: &str = &format!( "{}/{}_{}.txt", TEST_CASES_FOLDER, PREFIX_TLE_FILES, tle_count)[..];
-    if let Ok(_) = write_file(file_name, fs::read_to_string(from_path).unwrap().as_bytes()) {}
+    if write_file(file_name, fs::read_to_string(from_path).unwrap().as_bytes()).is_ok() {}
 }
 
 pub fn copy_file(from: &str, to: &str) -> Result<(), ExitFailure> {
@@ -126,37 +120,29 @@ pub fn load_testcases(
 
     if run_ac {
         let paths = glob(&format!("{}/{}*", TEST_CASES_FOLDER, PREFIX_AC_FILES))?;
-        for entry in paths {
-            if let Ok(path) = entry {
-                queue.push_back(path);
-            }
+        for path in paths.flatten() {
+            queue.push_back(path);
         }
     }
 
     if run_wa {
         let paths = glob(&format!("{}/{}*", TEST_CASES_FOLDER, PREFIX_WA_FILES))?;
-        for entry in paths {
-            if let Ok(path) = entry {
-                queue.push_back(path);
-            }
+        for path in paths.flatten() {
+            queue.push_back(path);
         }
     }
 
     if run_tle {
         let paths = glob(&format!("{}/{}*", TEST_CASES_FOLDER, PREFIX_TLE_FILES))?;
-        for entry in paths {
-            if let Ok(path) = entry {
-                queue.push_back(path);
-            }
+        for path in paths.flatten() {
+            queue.push_back(path);
         }
     }
 
     if run_rte {
         let paths = glob(&format!("{}/{}*", TEST_CASES_FOLDER, PREFIX_RTE_FILES))?;
-        for entry in paths {
-            if let Ok(path) = entry {
-                queue.push_back(path);
-            }
+        for path in paths.flatten() {
+            queue.push_back(path);
         }
     }
 
